@@ -1,6 +1,6 @@
 !***********************************************************************
 ! ISPACK FORTRAN SUBROUTINE LIBRARY FOR SCIENTIFIC COMPUTING
-! Copyright (C) 1998--2021 Keiichi Ishioka <ishioka@gfd-dennou.org>
+! Copyright (C) 1998--2022 Keiichi Ishioka <ishioka@gfd-dennou.org>
 !
 ! This library is free software; you can redistribute it and/or
 ! modify it under the terms of the GNU Lesser General Public
@@ -67,6 +67,8 @@
      PRINT '(A)','SSE=fma'
   ELSE IF(ICPU.EQ.30) THEN
      PRINT '(A)','SSE=avx512'
+  ELSE IF(ICPU.EQ.100) THEN
+     PRINT '(A)','SSE=sx'
   ELSE IF(ICPU.EQ.1000) THEN
      PRINT '(A)','SSE=fx'
   END IF
