@@ -1,6 +1,6 @@
 !***********************************************************************
 ! ISPACK FORTRAN SUBROUTINE LIBRARY FOR SCIENTIFIC COMPUTING
-! Copyright (C) 1998--2021 Keiichi Ishioka <ishioka@gfd-dennou.org>
+! Copyright (C) 1998--2022 Keiichi Ishioka <ishioka@gfd-dennou.org>
 !
 ! This library is free software; you can redistribute it and/or
 ! modify it under the terms of the GNU Lesser General Public
@@ -23,8 +23,8 @@
   INTEGER(8),PARAMETER :: JM=2**10,NTR=10
   INTEGER(8),PARAMETER :: MM=JM-1,IM=JM*2
   INTEGER(8),PARAMETER :: NM=MM,NN=NM
-  INTEGER(8) :: JV,N,M,L,LR,LI,LAS,ISEED,ICPU,IPOW,ITR,MAXTD
-  INTEGER(8) :: I,J,ICOM
+  INTEGER(8) :: JV,N,M,L,LR,LI,LAS,ICPU,IPOW,ITR,MAXTD
+  INTEGER(8) :: ICOM
   INTEGER :: IERR,NP,IP
   REAL(8) :: SLMAX,RAN,SLAMAX,SL,GFLOPS,RC,TIM0,TIM1  
   INTEGER(8),DIMENSION(:),ALLOCATABLE :: IT
@@ -82,6 +82,8 @@
         PRINT '(A)','SSE=fma'
      ELSE IF(ICPU.EQ.30) THEN
         PRINT '(A)','SSE=avx512'
+     ELSE IF(ICPU.EQ.100) THEN
+        PRINT '(A)','SSE=sx'
      ELSE IF(ICPU.EQ.1000) THEN
         PRINT '(A)','SSE=fx'
      END IF
