@@ -1,6 +1,6 @@
 !***********************************************************************
 ! ISPACK FORTRAN SUBROUTINE LIBRARY FOR SCIENTIFIC COMPUTING
-! Copyright (C) 1998--2021 Keiichi Ishioka <ishioka@gfd-dennou.org>
+! Copyright (C) 1998--2022 Keiichi Ishioka <ishioka@gfd-dennou.org>
 !
 ! This library is free software; you can redistribute it and/or
 ! modify it under the terms of the GNU Lesser General Public
@@ -26,7 +26,7 @@ SUBROUTINE SYTS2G(MM,NM,NN,IM,JM,JV,S,G,IT,T,P,R,JC,W,IPOW,ICOM)
   INTEGER(8) :: JI,JP1,JP2,JS,JE,K,I,IV,J,NBF
   INTEGER(8) :: IPDEST,IPSRC
   INTEGER(8) :: MN,M1,N1
-  INTEGER(8) :: ITH,NTH,NTHMAX
+  INTEGER(8) :: NTH
   REAL(8) :: S(*) ! S((MM/NP+1)*(2*(NN+1)-MM/NP*NP))
   REAL(8) :: G(*) ! G(0:IM-1,((JM/JV-1)/NP+1)*JV)
   INTEGER(8) :: IT(IM/2)  
@@ -35,20 +35,16 @@ SUBROUTINE SYTS2G(MM,NM,NN,IM,JM,JV,S,G,IT,T,P,R,JC,W,IPOW,ICOM)
   REAL(8) :: R(*) ! R(5*(MM/NP+1)*(2*NM-MM/NP*NP)/4+MM/NP+1)
   INTEGER(8) :: JC(*) ! JC((MM/NP+1)*(2*NM-MM/NP*NP)/16+MM/NP+1)
   REAL(8) :: W(*) ! W(2*JV*((JM/JV-1)/NP+1)*(MM/NP+1)*NP*2)
-  TYPE(C_PTR),ALLOCATABLE :: WSP(:)
-  TYPE(C_PTR),ALLOCATABLE :: WKP(:)
-  TYPE(C_PTR),ALLOCATABLE :: WGP(:)
-  LOGICAL,ALLOCATABLE :: LP(:)  
+  TYPE(C_PTR) :: WSP
+  TYPE(C_PTR) :: WKP
+  TYPE(C_PTR) :: WGP
   REAL(8),POINTER:: WS(:)
   REAL(8),POINTER:: WK(:)
   REAL(8),POINTER:: WG(:)
   INTEGER :: IP,NP,IERR,NB,ICOM4
 
-  !$ INTEGER :: omp_get_thread_num
-
   CALL SYGPRM(JM,JV,JR)
-
-  CALL MXGOMP(NTHMAX)    
+  CALL MXGOMP(NTH)    
 
   ICOM4=ICOM
   CALL MPI_COMM_SIZE(ICOM4,NP,IERR)
@@ -56,7 +52,7 @@ SUBROUTINE SYTS2G(MM,NM,NN,IM,JM,JV,S,G,IT,T,P,R,JC,W,IPOW,ICOM)
 
   JI=((JM/JV-1)/NP+1)*JV
 
-  !$omp parallel do num_threads(NTHMAX)
+  !$omp parallel do num_threads(NTH)
   DO IJ=1,IM*JI
      G(IJ)=0
   END DO
@@ -87,29 +83,15 @@ SUBROUTINE SYTS2G(MM,NM,NN,IM,JM,JV,S,G,IT,T,P,R,JC,W,IPOW,ICOM)
   END IF
 
   IF(MN.GE.1) THEN
-
-     NTH=MIN(MN,NTHMAX)
-     ITH=0
-     ALLOCATE(WKP(0:NTH-1))
-     ALLOCATE(WSP(0:NTH-1))
-     ALLOCATE(WGP(0:NTH-1))    
-     ALLOCATE(LP(0:NTH-1))
-     LP=.FALSE.
-
-     !$omp parallel private(K,NS,M,IJ,IE,WK,WS,WG,JS,JE,J,IPDEST,ITH) num_threads(NTH)
+     !$omp parallel private(K,NS,M,IJ,IE,WK,WS,WG,JS,JE,J,IPDEST,WKP,WSP,WGP) num_threads(NTH)
+     CALL MXALLC(WKP,JV*7*JR)
+     CALL C_F_POINTER(WKP,WK,[JV*7*JR])
+     CALL MXALLC(WSP,2*(NM+1))
+     CALL C_F_POINTER(WSP,WS,[2*(NM+1)])
+     CALL MXALLC(WGP,JM*2)
+     CALL C_F_POINTER(WGP,WG,[JM*2])
      !$omp do schedule(dynamic)
      DO K=0,MN-1
-        !$ ITH=omp_get_thread_num()
-        IF(.NOT.LP(ITH)) THEN
-           CALL MXALLC(WKP(ITH),JV*7*JR)
-           CALL C_F_POINTER(WKP(ITH),WK,[JV*7*JR])
-           CALL MXALLC(WSP(ITH),2*(NM+1))
-           CALL C_F_POINTER(WSP(ITH),WS,[2*(NM+1)])
-           CALL MXALLC(WGP(ITH),JM*2)
-           CALL C_F_POINTER(WGP(ITH),WG,[JM*2])
-           LP(ITH)=.TRUE.
-        END IF
-
         IE=5*K*(2*NM-NP*(K-1))/4+K+1
         IJ=K*(2*NM-NP*(K-1))/16+K+1     
         M=K*NP+IP+MOD(K,2)*(NP-2*IP-1)
@@ -132,43 +114,21 @@ SUBROUTINE SYTS2G(MM,NM,NN,IM,JM,JV,S,G,IT,T,P,R,JC,W,IPOW,ICOM)
         END DO
      END DO
      !$omp end do
+     CALL MXFREE(WKP)
+     CALL MXFREE(WSP)
+     CALL MXFREE(WGP)                
      !$omp end parallel
 
-     DO ITH=0,NTH-1
-        IF(LP(ITH)) THEN
-           CALL MXFREE(WKP(ITH))
-           CALL MXFREE(WSP(ITH))
-           CALL MXFREE(WGP(ITH))                
-        END IF
-     END DO
-
-     DEALLOCATE(WSP)  
-     DEALLOCATE(WKP)
-     DEALLOCATE(WGP)  
-     DEALLOCATE(LP)
-
   END IF
 
   CALL MPI_ALLTOALL(W(NBF+1),NB,MPI_REAL8,W,NB,MPI_REAL8,ICOM4,IERR)
   
   IF(JP1.NE.0) THEN  
-
-     NTH=MIN((JP2-JP1+1)/JV,NTHMAX)
-     ALLOCATE(WKP(0:NTH-1))
-     ALLOCATE(LP(0:NTH-1))
-     LP=.FALSE.
-
-     ITH=0
-
-     !$omp parallel private(JD,M,K,I,IPSRC,IV,ITH,WK) num_threads(NTH)
+     !$omp parallel private(JD,M,K,I,IPSRC,IV,WKP,WK) num_threads(NTH)
+     CALL MXALLC(WKP,JV*IM)
+     CALL C_F_POINTER(WKP,WK,[JV*IM])
      !$omp do schedule(dynamic)
      DO JD=1,(JP2-JP1+1)/JV
-        !$ ITH=omp_get_thread_num()
-        IF(.NOT.LP(ITH)) THEN
-           CALL MXALLC(WKP(ITH),JV*IM)
-           CALL C_F_POINTER(WKP(ITH),WK,[JV*IM])
-           LP(ITH)=.TRUE.
-        END IF
         DO M=0,MM
            K=M/NP
            IF(MOD(K,2).EQ.0) THEN
@@ -194,16 +154,9 @@ SUBROUTINE SYTS2G(MM,NM,NN,IM,JM,JV,S,G,IT,T,P,R,JC,W,IPOW,ICOM)
         END DO
      END DO
      !$omp end do
+     CALL MXFREE(WKP)     
      !$omp end parallel
 
-     DO ITH=0,NTH-1
-        IF(LP(ITH)) THEN
-           CALL MXFREE(WKP(ITH))
-        END IF
-     END DO
-     DEALLOCATE(WKP)
-     DEALLOCATE(LP)
-
   END IF
 
 END SUBROUTINE SYTS2G
