@@ -1,6 +1,6 @@
 !***********************************************************************
 ! ISPACK FORTRAN SUBROUTINE LIBRARY FOR SCIENTIFIC COMPUTING
-! Copyright (C) 1998--2021 Keiichi Ishioka <ishioka@gfd-dennou.org>
+! Copyright (C) 1998--2022 Keiichi Ishioka <ishioka@gfd-dennou.org>
 !
 ! This library is free software; you can redistribute it and/or
 ! modify it under the terms of the GNU Lesser General Public
@@ -26,7 +26,7 @@ SUBROUTINE SYTV2S(MM,NM,NN,IM,JM,JV,S1,S2,G1,G2,IT,T,P,R,JC,W,IPOW,ICOM)
   INTEGER(8) :: JI,JP1,JP2,JS,JE,K,I,IV,J,NBF
   INTEGER(8) :: IPDEST,IPSRC
   INTEGER(8) :: MN,M1,N1
-  INTEGER(8) :: ITH,NTH,NTHMAX
+  INTEGER(8) :: NTH
   REAL(8) :: S1(*) ! S1((MM/NP+1)*(2*(NN+1)-MM/NP*NP))
   REAL(8) :: S2(*) ! S2((MM/NP+1)*(2*(NN+1)-MM/NP*NP))  
   REAL(8) :: G1(*) ! G1(0:IM-1,((JM/JV-1)/NP+1)*JV)
@@ -37,20 +37,16 @@ SUBROUTINE SYTV2S(MM,NM,NN,IM,JM,JV,S1,S2,G1,G2,IT,T,P,R,JC,W,IPOW,ICOM)
   REAL(8) :: R(*) ! R(5*(MM/NP+1)*(2*NM-MM/NP*NP)/4+MM/NP+1)
   INTEGER(8) :: JC(*) ! JC((MM/NP+1)*(2*NM-MM/NP*NP)/16+MM/NP+1)
   REAL(8) :: W(*) ! W(2*JV*((JM/JV-1)/NP+1)*(MM/NP+1)*NP*2*2)
-  TYPE(C_PTR),ALLOCATABLE :: WSP(:)
-  TYPE(C_PTR),ALLOCATABLE :: WKP(:)
-  TYPE(C_PTR),ALLOCATABLE :: WGP(:)
-  LOGICAL,ALLOCATABLE :: LP(:)  
+  TYPE(C_PTR) :: WSP
+  TYPE(C_PTR) :: WKP
+  TYPE(C_PTR) :: WGP
   REAL(8),POINTER:: WS(:)
   REAL(8),POINTER:: WK(:)
   REAL(8),POINTER:: WG(:,:)
   INTEGER :: IP,NP,IERR,NB,ICOM4
 
-  !$ INTEGER :: omp_get_thread_num
-
   CALL SYGPRM(JM,JV,JR)
-
-  CALL MXGOMP(NTHMAX)   
+  CALL MXGOMP(NTH)   
 
   ICOM4=ICOM
   CALL MPI_COMM_SIZE(ICOM4,NP,IERR)
@@ -61,7 +57,7 @@ SUBROUTINE SYTV2S(MM,NM,NN,IM,JM,JV,S1,S2,G1,G2,IT,T,P,R,JC,W,IPOW,ICOM)
   NB=JI*2*(MM/NP+1)
   NBF=NB*NP
 
-  !$omp parallel do num_threads(NTHMAX)
+  !$omp parallel do num_threads(NTH)
   DO L=1,(MM/NP+1)*(2*(NN+1)-MM/NP*NP)
      S1(L)=0
      S2(L)=0     
@@ -77,30 +73,18 @@ SUBROUTINE SYTV2S(MM,NM,NN,IM,JM,JV,S1,S2,G1,G2,IT,T,P,R,JC,W,IPOW,ICOM)
   END IF
   
   IF(JP1.NE.0) THEN  
-
-     NTH=MIN((JP2-JP1+1)/JV,NTHMAX)
-     ALLOCATE(WKP(0:NTH-1))
-     ALLOCATE(LP(0:NTH-1))
-     LP=.FALSE.
-
-     ITH=0
-
-     !$omp parallel private(JD,M,K,I,IPSRC,IV,ITH,WK) num_threads(NTH)
+     !$omp parallel private(JD,M,K,I,IPSRC,IV,WKP,WK) num_threads(NTH)
+     CALL MXALLC(WKP,JV*IM*2)
+     CALL C_F_POINTER(WKP,WK,[JV*IM*2])
      !$omp do schedule(dynamic)
      DO JD=1,(JP2-JP1+1)/JV
-        !$ ITH=omp_get_thread_num()
-        IF(.NOT.LP(ITH)) THEN
-           CALL MXALLC(WKP(ITH),JV*IM*2)
-           CALL C_F_POINTER(WKP(ITH),WK,[JV*IM*2])
-           LP(ITH)=.TRUE.
-        END IF
         DO IV=1,JV
            DO I=1,IM
               WK(IV+JV*(I-1))=G1(I+IM*(IV-1+JV*(JD-1)))
               WK(JV*IM+IV+JV*(I-1))=G2(I+IM*(IV-1+JV*(JD-1)))              
            END DO
         END DO
-        CALL FXRTFA(JV,IM,WK,IT,T)
+        CALL FXRTFA(JV,IM,WK(1),IT,T) ! gfortranؤб
         CALL FXRTFA(JV,IM,WK(JV*IM+1),IT,T)        
         DO M=0,MM
            K=M/NP
@@ -116,16 +100,9 @@ SUBROUTINE SYTV2S(MM,NM,NN,IM,JM,JV,S1,S2,G1,G2,IT,T,P,R,JC,W,IPOW,ICOM)
         END DO
      END DO
      !$omp end do
+     CALL MXFREE(WKP)     
      !$omp end parallel
 
-     DO ITH=0,NTH-1
-        IF(LP(ITH)) THEN
-           CALL MXFREE(WKP(ITH))
-        END IF
-     END DO
-     DEALLOCATE(WKP)
-     DEALLOCATE(LP)
-
   END IF
 
   CALL MPI_ALLTOALL(W,NB,MPI_REAL8,W(NBF*2+1),NB,MPI_REAL8,ICOM4,IERR)
@@ -145,28 +122,15 @@ SUBROUTINE SYTV2S(MM,NM,NN,IM,JM,JV,S1,S2,G1,G2,IT,T,P,R,JC,W,IPOW,ICOM)
   END IF
 
   IF(MN.GE.1) THEN
-
-     NTH=MIN(MN,NTHMAX)
-     ITH=0
-     ALLOCATE(WKP(0:NTH-1))
-     ALLOCATE(WSP(0:NTH-1))
-     ALLOCATE(WGP(0:NTH-1))    
-     ALLOCATE(LP(0:NTH-1))
-     LP=.FALSE.
-
-     !$omp parallel private(K,NS,M,IJ,IE,WK,WS,WG,JS,JE,J,IPDEST,ITH) num_threads(NTH)
+     !$omp parallel private(K,NS,M,IJ,IE,WK,WS,WG,JS,JE,J,IPDEST,WKP,WSP,WGP) num_threads(NTH)
+     CALL MXALLC(WKP,JV*11*JR)
+     CALL C_F_POINTER(WKP,WK,[JV*11*JR])
+     CALL MXALLC(WSP,4*(NM+1))
+     CALL C_F_POINTER(WSP,WS,[4*(NM+1)])
+     CALL MXALLC(WGP,JM*2*2)
+     CALL C_F_POINTER(WGP,WG,[JM*2,2_8])
      !$omp do schedule(dynamic)
      DO K=0,MN-1
-        !$ ITH=omp_get_thread_num()
-        IF(.NOT.LP(ITH)) THEN
-           CALL MXALLC(WKP(ITH),JV*11*JR)
-           CALL C_F_POINTER(WKP(ITH),WK,[JV*11*JR])
-           CALL MXALLC(WSP(ITH),4*(NM+1))
-           CALL C_F_POINTER(WSP(ITH),WS,[4*(NM+1)])
-           CALL MXALLC(WGP(ITH),JM*2*2)
-           CALL C_F_POINTER(WGP(ITH),WG,[JM*2,2_8])
-           LP(ITH)=.TRUE.
-        END IF
         JS=1
         IPDEST=-1
         DO WHILE(JS.LE.2*JM) 
@@ -190,21 +154,11 @@ SUBROUTINE SYTV2S(MM,NM,NN,IM,JM,JV,S1,S2,G1,G2,IT,T,P,R,JC,W,IPOW,ICOM)
         END IF
      END DO
      !$omp end do
+     CALL MXFREE(WKP)
+     CALL MXFREE(WSP)
+     CALL MXFREE(WGP)                
      !$omp end parallel
 
-     DO ITH=0,NTH-1
-        IF(LP(ITH)) THEN
-           CALL MXFREE(WKP(ITH))
-           CALL MXFREE(WSP(ITH))
-           CALL MXFREE(WGP(ITH))                
-        END IF
-     END DO
-
-     DEALLOCATE(WSP)  
-     DEALLOCATE(WKP)
-     DEALLOCATE(WGP)  
-     DEALLOCATE(LP)
-
   END IF
 
 END SUBROUTINE SYTV2S
